@@ -21,13 +21,13 @@ def poetry_project() -> Poetry:
 @lru_cache(maxsize=None)
 def poetry_project_name() -> str:
     """Get the name of the current Poerty project."""
-    return poetry_project().pyproject.poetry_config["name"]
+    return str(poetry_project().pyproject.poetry_config["name"])
 
 
 @lru_cache(maxsize=None)
 def poetry_project_version() -> str:
     """Get the version of the current Poerty project."""
-    return poetry_project().pyproject.poetry_config["version"]
+    return str(poetry_project().pyproject.poetry_config["version"])
 
 
 @lru_cache(maxsize=None)
@@ -40,4 +40,4 @@ def poetry_wheel_builder() -> WheelBuilder:
 def poetry_wheelname() -> str:
     """Get poetry properly formatted wheelname from WheelBuilder instance."""
     builder = poetry_wheel_builder()
-    return builder.wheel_filename
+    return str(builder.wheel_filename)
